@@ -19,9 +19,9 @@
 import os
 import time
 import datetime
-import pycanberra
-from xdg import BaseDirectory
 from gi.repository import GObject, Gio, GnomeDesktop, Notify
+from . import pycanberra
+from gnomeclocks import GNOMECLOCKS_DATADIR
 
 
 def N_(message):
@@ -29,40 +29,27 @@ def N_(message):
 
 
 class Dirs:
-    @staticmethod
-    def get_data_dir():
-        try:
-            path = os.environ['GNOME_CLOCKS_DATA_PATH']
-        except:
-            path = "../data"
-        return path
+    if os.path.exists(os.path.join("gnome-clocks.doap")):
+        print("Running from a source checkout, loading local data")
+        datadir = os.path.join("data")
+    else:
+        datadir = GNOMECLOCKS_DATADIR
 
     @staticmethod
-    def get_image_dir():
-        try:
-            path = os.environ['GNOME_CLOCKS_IMAGE_PATH']
-        except:
-            path = "../data"
-        return path
+    def get_css_dir():
+        return os.path.join(Dirs.datadir, "css")
 
     @staticmethod
-    def get_locale_dir():
-        try:
-            path = os.environ['GNOME_CLOCKS_LOCALE_PATH']
-        except:
-            path = "locale"
-        return path
-
-    @staticmethod
-    def get_user_data_dir():
-        return BaseDirectory.save_data_path("gnome-clocks")
+    def get_images_dir():
+        return os.path.join(Dirs.datadir, "images")
 
 
 class SystemSettings:
+    settings = Gio.Settings.new('org.gnome.desktop.interface')
+
     @staticmethod
     def get_clock_format():
-        settings = Gio.Settings.new('org.gnome.desktop.interface')
-        systemClockFormat = settings.get_string('clock-format')
+        systemClockFormat = SystemSettings.settings.get_string('clock-format')
         return systemClockFormat
 
 
@@ -169,25 +156,30 @@ class WallClock(GObject.GObject):
 
 
 class Alert:
-    def __init__(self, soundid, msg):
+    settings = Gio.Settings.new('org.gnome.desktop.sound')
+
+    def __init__(self, soundid, title, msg):
         try:
             self.canberra = pycanberra.Canberra()
         except Exception as e:
-            print "Sound will not be available: ", e
+            print("Sound will not be available: ", e)
             self.canberra = None
 
+        self.soundtheme = Alert.settings.get_string('theme-name')
         self.soundid = soundid
 
         self.notification = None
         if Notify.is_initted() or Notify.init("GNOME Clocks"):
-            self.notification = Notify.Notification.new("Clocks", msg, 'clocks')
+            self.notification = Notify.Notification.new(title, msg, "gnome-clocks")
+            self.notification.set_hint_string("desktop-entry", "gnome-clocks")
         else:
-            print "Error: Could not trigger Alert"
+            print("Error: Could not trigger Alert")
 
     def show(self):
         if self.canberra:
             self.canberra.play(1,
                                pycanberra.CA_PROP_EVENT_ID, self.soundid,
+                               pycanberra.CA_PROP_CANBERRA_XDG_THEME_NAME, self.soundtheme,
                                pycanberra.CA_PROP_MEDIA_ROLE, "alarm",
                                None)
         if self.notification:
